////////////////////////////////////////////////////////////////////////////////////////////////
//                                                                                            //
//                                       WATTO STUDIOS                                        //
//                             Java Code, Programs, and Software                              //
//                                    http://www.watto.org                                    //
//                                                                                            //
//                           Copyright (C) 2004-2010  WATTO Studios                           //
//                                                                                            //
// This program is free software; you can redistribute it and/or modify it under the terms of //
// the GNU General Public License published by the Free Software Foundation; either version 2 //
// of the License, or (at your option) any later versions. This program is distributed in the //
// hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranties //
// of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License //
// at http://www.gnu.org for more details. For updates and information about this program, go //
// to the WATTO Studios website at http://www.watto.org or email watto@watto.org . Thanks! :) //
//                                                                                            //
////////////////////////////////////////////////////////////////////////////////////////////////

package org.watto.program.android.sync.steam;

import java.util.ArrayList;
import android.content.ContentProviderOperation;
import android.content.ContentResolver;
import android.content.Context;
import android.provider.ContactsContract;


/***********************************************************************************************
Executes a queue of <code>ContentProviderOperation</code>s on a <code>ContentResolver</code>
contacts provider
***********************************************************************************************/
public class BatchOperation {

  ContentResolver contentResolver;

  /** A queue of operations **/
  ArrayList<ContentProviderOperation> contentOperations;


  /***********************************************************************************************
  Constructor, setting the <code>Context</code> and <code>ContentResolver</code>
  ***********************************************************************************************/
  public BatchOperation(Context context, ContentResolver resolver){
    this.contentResolver = resolver;
    this.contentOperations = new ArrayList<ContentProviderOperation>();
  }


  /***********************************************************************************************
  Adds a <code>ContentProviderOperation</code> to the queue
  @param operation the <code>ContentProviderOperation</code> to add
  ***********************************************************************************************/
  public void add(ContentProviderOperation operation){
    contentOperations.add(operation);
  }


  /***********************************************************************************************
  Runs all the <i>operations</i> in the queue
  ***********************************************************************************************/
  public void execute(){
    if (contentOperations.size() == 0) {
      return;
    }

    try {
      contentResolver.applyBatch(ContactsContract.AUTHORITY,contentOperations);
    }
    catch (Throwable t) {}

    contentOperations.clear();
  }
  
  
  /***********************************************************************************************
  Clears all the <i>operations</i> from the queue
  ***********************************************************************************************/
  public void clear(){
    contentOperations.clear();
  }


  /***********************************************************************************************
  Gets the number of <i>operations</i> in the queue
  @return the number of operations
  ***********************************************************************************************/
  public int size(){
    return contentOperations.size();
  }

}
