////////////////////////////////////////////////////////////////////////////////////////////////
//                                                                                            //
//                                       WATTO STUDIOS                                        //
//                             Java Code, Programs, and Software                              //
//                                    http://www.watto.org                                    //
//                                                                                            //
//                           Copyright (C) 2004-2010  WATTO Studios                           //
//                                                                                            //
// This program is free software; you can redistribute it and/or modify it under the terms of //
// the GNU General Public License published by the Free Software Foundation; either version 2 //
// of the License, or (at your option) any later versions. This program is distributed in the //
// hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranties //
// of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License //
// at http://www.gnu.org for more details. For updates and information about this program, go //
// to the WATTO Studios website at http://www.watto.org or email watto@watto.org . Thanks! :) //
//                                                                                            //
////////////////////////////////////////////////////////////////////////////////////////////////

package org.watto.program.android.sync.steam;

import java.net.URL;


/***********************************************************************************************
Details about a single Steam friend
***********************************************************************************************/
public class SteamFriend {

  /** The Steam user ID **/
  long userID = -1; // Custom Column "UserIdData"
  /** The users user name **/
  String username = null;
  /** The online state of the user (online, offline, etc) **/
  String onlineState = null;
  /** The state message of the user (eg Last Online 4 hours ago) **/
  String stateMessage = null;
  /** The URL to the photo of this user **/
  URL photo = null;
  /** The users custom URL **/
  String customUrl = null;
  /** The date that the user created their Steam account **/
  String memberSince = null;
  /** The Steam Rating of the user **/
  double steamRating = -1;
  /** The number of hours the user played in the last 2 weeks **/
  double hoursPlayed = -1;
  /** The user's headline message **/
  String headline = null;
  /** The users location **/
  String location = null;
  /** The users real name **/
  String realName = null;
  /** The user's summary message **/
  String summary = null;
  /** The user's most played game **/
  String mostPlayedGame = null;
  /** The number of hours the user has played their most played game **/
  double mostPlayedGameHours = 0;
  /** The website of the user **/
  String website = null;
  /** The title of the user's website **/
  String websiteTitle = null;
  /** The primary group that the user belongs to **/
  String primaryGroup = null;
  /** The users favorite game **/
  String favoriteGame = null;


  /***********************************************************************************************
  Constructor
  ***********************************************************************************************/
  public SteamFriend(){}


  /***********************************************************************************************
  Creates a new Steam friend with a <i>userID</i>
  @param userID the user ID of the friend
  ***********************************************************************************************/
  public SteamFriend(long userID){
    this.userID = userID;
  }


  /***********************************************************************************************
  Gets the custom url of this user
  @return the <i>customUrl</i>
  ***********************************************************************************************/
  public String getCustomUrl(){
    return customUrl;
  }


  /***********************************************************************************************
  Gets the favorite game of this user
  @return the <i>favoriteGame</i>
  ***********************************************************************************************/
  public String getFavoriteGame(){
    return favoriteGame;
  }


  /***********************************************************************************************
  Gets the headline of this user
  @return the <i>headline</i>
  ***********************************************************************************************/
  public String getHeadline(){
    return headline;
  }


  /***********************************************************************************************
  Gets the number of hours played for this user
  @return the <i>hoursPlayed</i>
  ***********************************************************************************************/
  public double getHoursPlayed(){
    return hoursPlayed;
  }


  /***********************************************************************************************
  Gets the location of this user
  @return the <i>location</i>
  ***********************************************************************************************/
  public String getLocation(){
    return location;
  }


  /***********************************************************************************************
  Gets the member since date of this user
  @return the <i>memberSince</i>
  ***********************************************************************************************/
  public String getMemberSince(){
    return memberSince;
  }


  /***********************************************************************************************
  Gets the most played game of this user
  @return the <i>mostPlayedGame</i>
  ***********************************************************************************************/
  public String getMostPlayedGame(){
    return mostPlayedGame;
  }


  /***********************************************************************************************
  Gets the number of hours playing the most played game of this user
  @return the <i>mostPlayedGameHours</i>
  ***********************************************************************************************/
  public double getMostPlayedGameHours(){
    return mostPlayedGameHours;
  }


  /***********************************************************************************************
  Gets the online state of this user
  @return the <i>onlineState</i>
  ***********************************************************************************************/
  public String getOnlineState(){
    return onlineState;
  }


  /***********************************************************************************************
  Gets the URL for the photo of this user
  @return the <i>photo</i> URL
  ***********************************************************************************************/
  public URL getPhoto(){
    return photo;
  }


  /***********************************************************************************************
  Gets the primary group of this user
  @return the <i>primaryGroup</i>
  ***********************************************************************************************/
  public String getPrimaryGroup(){
    return primaryGroup;
  }


  /***********************************************************************************************
  Gets the real name of this user
  @return the <i>realName</i>
  ***********************************************************************************************/
  public String getRealName(){
    return realName;
  }


  /***********************************************************************************************
  Gets the state message of this user
  @return the <i>stateMessage</i>
  ***********************************************************************************************/
  public String getStateMessage(){
    return stateMessage;
  }


  /***********************************************************************************************
  Gets the steam rating of this user
  @return the <i>steamRating</i>
  ***********************************************************************************************/
  public double getSteamRating(){
    return steamRating;
  }


  /***********************************************************************************************
  Gets the summary of this user
  @return the <i>summary</i>
  ***********************************************************************************************/
  public String getSummary(){
    return summary;
  }


  /***********************************************************************************************
  Gets the user ID of this user
  @return the <i>userID</i>
  ***********************************************************************************************/
  public long getUserID(){
    return userID;
  }


  /***********************************************************************************************
  Gets the username of this user
  @return the <i>username</i>
  ***********************************************************************************************/
  public String getUsername(){
    return username;
  }


  /***********************************************************************************************
  Gets the website of this user
  @return the <i>website</i>
  ***********************************************************************************************/
  public String getWebsite(){
    return website;
  }


  /***********************************************************************************************
  Gets the title of the website of this user
  @return the <i>websiteTitle</i>
  ***********************************************************************************************/
  public String getWebsiteTitle(){
    return websiteTitle;
  }


  /***********************************************************************************************
  Sets the custom url of this user
  @param customUrl the custom url of this user
  ***********************************************************************************************/
  public void setCustomUrl(String customUrl){
    this.customUrl = customUrl;
  }


  /***********************************************************************************************
  Sets the favorite game of this user
  @param favoriteGame the users favorite game
  ***********************************************************************************************/
  public void setFavoriteGame(String favoriteGame){
    this.favoriteGame = favoriteGame;
  }


  /***********************************************************************************************
  Sets the headline of this user
  @param headline the headline of this user
  ***********************************************************************************************/
  public void setHeadline(String headline){
    this.headline = headline;
  }


  /***********************************************************************************************
  Sets the number of hours played by this user
  @param hoursPlayed the number of hours played by this user
  ***********************************************************************************************/
  public void setHoursPlayed(double hoursPlayed){
    this.hoursPlayed = hoursPlayed;
  }


  /***********************************************************************************************
  Sets the location of this user
  @param location the location of this user
  ***********************************************************************************************/
  public void setLocation(String location){
    this.location = location;
  }


  /***********************************************************************************************
  Sets the member since date of this user
  @param memberSince the member since date of this user
  ***********************************************************************************************/
  public void setMemberSince(String memberSince){
    this.memberSince = memberSince;
  }


  /***********************************************************************************************
  Sets the most played game of this user
  @param mostPlayedGame the most played game
  ***********************************************************************************************/
  public void setMostPlayedGame(String mostPlayedGame){
    this.mostPlayedGame = mostPlayedGame;
  }


  /***********************************************************************************************
  Sets the number of hours playing the most played game
  @param mostPlayedGameHours the number of hours playing the most played game
  ***********************************************************************************************/
  public void setMostPlayedGameHours(double mostPlayedGameHours){
    this.mostPlayedGameHours = mostPlayedGameHours;
  }


  /***********************************************************************************************
  Sets the online state of this user
  @param onlineState the online state of this user
  ***********************************************************************************************/
  public void setOnlineState(String onlineState){
    this.onlineState = onlineState;
  }


  /***********************************************************************************************
  Sets the URL to the photo of this user
  @param photo the URL to the photo of this user
  ***********************************************************************************************/
  public void setPhoto(URL photo){
    this.photo = photo;
  }


  /***********************************************************************************************
  Sets the primary group of this user
  @param primaryGroup the primary group of this user
  ***********************************************************************************************/
  public void setPrimaryGroup(String primaryGroup){
    this.primaryGroup = primaryGroup;
  }


  /***********************************************************************************************
  Sets the real name of this user
  @param realName the real name of this user
  ***********************************************************************************************/
  public void setRealName(String realName){
    if (realName != null && realName.equals("null")) {
      realName = null;
    }
    this.realName = realName;
  }


  /***********************************************************************************************
  Sets the state message of this user
  @param stateMessage the state message of this user
  ***********************************************************************************************/
  public void setStateMessage(String stateMessage){
    this.stateMessage = stateMessage;
  }


  /***********************************************************************************************
  Sets the steam rating of this user
  @param steamRating the steam rating of this user
  ***********************************************************************************************/
  public void setSteamRating(double steamRating){
    this.steamRating = steamRating;
  }


  /***********************************************************************************************
  Sets the summary of this user
  @param summary the summary of this user
  ***********************************************************************************************/
  public void setSummary(String summary){
    this.summary = summary;
  }


  /***********************************************************************************************
  Sets the User ID of this user
  @param userID the User ID of this user
  ***********************************************************************************************/
  public void setUserID(long userID){
    this.userID = userID;
  }


  /***********************************************************************************************
  Sets the username of this user
  @param username the username of this user
  ***********************************************************************************************/
  public void setUsername(String username){
    if (username != null && username.equals("null")) {
      username = null;
    }
    this.username = username;
  }


  /***********************************************************************************************
  Sets the website of this user
  @param website the <i>website</i>
  ***********************************************************************************************/
  public void setWebsite(String website){
    if (website != null && website.equals("null")) {
      website = null;
    }
    this.website = website;
  }


  /***********************************************************************************************
  Sets the title of the website of this user
  @param websiteTitle the title of the website
  ***********************************************************************************************/
  public void setWebsiteTitle(String websiteTitle){
    this.websiteTitle = websiteTitle;
  }

}
