////////////////////////////////////////////////////////////////////////////////////////////////
//                                                                                            //
//                                       WATTO STUDIOS                                        //
//                             Java Code, Programs, and Software                              //
//                                    http://www.watto.org                                    //
//                                                                                            //
//                           Copyright (C) 2004-2010  WATTO Studios                           //
//                                                                                            //
// This program is free software; you can redistribute it and/or modify it under the terms of //
// the GNU General Public License published by the Free Software Foundation; either version 2 //
// of the License, or (at your option) any later versions. This program is distributed in the //
// hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranties //
// of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License //
// at http://www.gnu.org for more details. For updates and information about this program, go //
// to the WATTO Studios website at http://www.watto.org or email watto@watto.org . Thanks! :) //
//                                                                                            //
////////////////////////////////////////////////////////////////////////////////////////////////

package org.watto.program.android.sync.steam;

import org.watto.android.WSAboutScreen;
import org.watto.android.event.WSViewClickableInterface;
import org.watto.android.event.listener.WSViewClickableListener;
import org.watto.program.android.sync.steam.R;
import org.watto.program.android.sync.steam.authenticator.AuthenticatorPreferences;
import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.provider.Settings;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;


/***********************************************************************************************
Shows a helper screen that shows the user how to create a new account. Also puts an icon in the
applications list on the phone, so the user knows that it has been installed.
***********************************************************************************************/
public class SyncInfoActivity extends Activity implements WSViewClickableInterface {

  /***********************************************************************************************
  Performs an action when a single-click event is triggered on a <code>View</code>
  @param source the <code>View</code> that triggered the event
  @return <b>true</b> if the event was handled by this class<br />
          <b>false</b> if the event wasn't handled by this class, and thus should be passed on to
          the parent class for handling.
  ***********************************************************************************************/
  public boolean onClick(View source){
    if (source.getId() == R.id.button_open_accounts) {
      Intent accountsActivity = new Intent(Settings.ACTION_SYNC_SETTINGS);
      startActivity(accountsActivity);
      return true;
    }
    return false;
  }

  /***********************************************************************************************
  Creates the <code>Activity</code> from the XML file
  @param savedInstanceState the saved state of the <code>Activity</code>
  ***********************************************************************************************/
  public void onCreate(Bundle savedInstanceState){
    super.onCreate(savedInstanceState);

    // Creates the view from the XML file
    setContentView(R.layout.sync_info_activity);
    
    // Sets the listener on the screen button
    Button button = (Button)findViewById(R.id.button_open_accounts);
    button.setOnClickListener(new WSViewClickableListener(this));
  }


  /***********************************************************************************************
  Creates the <code>Menu</code> from the XML file when the Options button is pressed
  @param menu the <code>Menu</code> <code>View</code> to populate with menu items
  @return <b>true</b> to display the menu, <br />
          <b>false</b> to keep the menu hidden.
  ***********************************************************************************************/
  public boolean onCreateOptionsMenu(Menu menu){
    MenuInflater inflater = getMenuInflater();
    inflater.inflate(R.menu.sync_info_activity,menu);
    return true;
  }


  /***********************************************************************************************
  Performs an action when a <code>MenuItem</code> is selected in the Options menu
  @param item the <code>MenuItem</code> that was selected
  @return <b>true</b> if the event was handled by this class<br />
          <b>false</b> if the event wasn't handled by this class, and thus should be passed on to
          the parent class for handling.
  ***********************************************************************************************/
  public boolean onOptionsItemSelected(MenuItem item){
    int id = item.getItemId();

    if (id == R.id.menu_settings) {
      showSettings();
      return true;
    }
    else if (id == R.id.menu_about) {
      showAbout();
      return true;
    }
    return false;
  }


  /***********************************************************************************************
  Shows the settings <code>Activity</code>
  ***********************************************************************************************/
  public void showSettings(){
    Intent settingsActivity = new Intent(getBaseContext(),AuthenticatorPreferences.class);
    startActivity(settingsActivity);
  }


  /***********************************************************************************************
  Shows the about <code>Activity</code>
  ***********************************************************************************************/
  public void showAbout(){
    Intent aboutActivity = new Intent(getBaseContext(),WSAboutScreen.class);
    startActivity(aboutActivity);
  }

}