////////////////////////////////////////////////////////////////////////////////////////////////
//                                                                                            //
//                                       WATTO STUDIOS                                        //
//                             Java Code, Programs, and Software                              //
//                                    http://www.watto.org                                    //
//                                                                                            //
//                           Copyright (C) 2004-2010  WATTO Studios                           //
//                                                                                            //
// This program is free software; you can redistribute it and/or modify it under the terms of //
// the GNU General Public License published by the Free Software Foundation; either version 2 //
// of the License, or (at your option) any later versions. This program is distributed in the //
// hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranties //
// of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License //
// at http://www.gnu.org for more details. For updates and information about this program, go //
// to the WATTO Studios website at http://www.watto.org or email watto@watto.org . Thanks! :) //
//                                                                                            //
////////////////////////////////////////////////////////////////////////////////////////////////

package org.watto.program.android.sync.steam.authenticator;

import org.watto.android.Settings;
import org.watto.android.event.WSViewClickableInterface;
import org.watto.android.event.listener.WSViewClickableListener;
import org.watto.program.android.sync.steam.R;
import android.accounts.AccountAuthenticatorActivity;
import android.accounts.AccountManager;
import android.app.AlarmManager;
import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.view.View;
import android.widget.EditText;


/***********************************************************************************************
Activity which displays login screen to the user
***********************************************************************************************/
public class AuthenticatorActivity extends AccountAuthenticatorActivity implements WSViewClickableInterface {

  boolean addAccount = false;

  public int ACTIVITY_CALL_BROWSER = 2;


  /***********************************************************************************************
  Called when response is received from the server for authentication request. See
  onAuthenticationResult(). Sets the AccountAuthenticatorResult which is sent back to the caller.
  Also sets the authToken in AccountManager for this account.
  @param the confirmCredentials result.
  ***********************************************************************************************/
  public void createAccount(){

    AccountManager accountManager = AccountManager.get(this);
    //SteamAuthenticator.createAccount(accountManager);

    // Allow regular syncing for Android 2.2+
    int apiVersion = android.os.Build.VERSION.SDK_INT;
    if (apiVersion <= 7) {
      // <= Android 2.1
      AlarmManager alarmManager = (AlarmManager)this.getSystemService(Context.ALARM_SERVICE);
      SteamAuthenticator.createAccount(accountManager,alarmManager,getBaseContext());
    }
    else if (apiVersion >= 8) {
      // Android 2.2+
      SteamAuthenticator.createAccount(accountManager,getContentResolver());
    }

    Intent accountIntent = SteamAuthenticator.getAccountIntent(accountManager);
    setAccountAuthenticatorResult(accountIntent.getExtras());
    setResult(RESULT_OK,accountIntent);

    finish();
  }



  /***********************************************************************************************
  Performs an action when a single-click event is triggered on a <code>View</code>
  @param source the <code>View</code> that triggered the event
  @return <b>true</b> if the event was handled by this class<br />
          <b>false</b> if the event wasn't handled by this class, and thus should be passed on to
          the parent class for handling.
  ***********************************************************************************************/
  public boolean onClick(View source){
    int id = source.getId();
    if (id == R.id.button_add_account || id == R.id.button_update_credentials) {
      // Set the Custom URL for the account
      try {
        String customUrl = ((EditText)findViewById(R.id.tf_custom_url)).getText().toString(); 
        SteamAuthenticator.setCustomUrl(customUrl);
      }
      catch (Throwable t){
      }
      
      // Show the "please wait" window
      setContentView(R.layout.verifying);

      // Check that the credentials are OK
      SteamAuthenticator.confirmCredentials();

      if (addAccount) {
        // Create the new account
        createAccount();
      }
      else {
        // Just update the current account with the new credentials
        updateAccount();
      }

      finish();
    }
    else if (id == R.id.button_visit_steam_website){
      Intent intent = new Intent(Intent.ACTION_VIEW,Uri.parse("https://steamcommunity.com/"));
      startActivity(intent);
    }
    else {
      return false;
    }
    return true;
  }


  /***********************************************************************************************
  Creates the <code>Activity</code>
  ***********************************************************************************************/
  public void onCreate(Bundle bundle){
    super.onCreate(bundle);

    // Set the Settings Context
    Settings.setApplication(this.getBaseContext());

    addAccount = false;

    // Get the Intent that started this activity
    Intent intent = getIntent();

    // Get the action that is triggering this Activity
    String action = intent.getStringExtra("action");

    if (action.equals("addAccount")) {
      addAccount = true;

      // Load the Add Account information screen
      setContentView(R.layout.add_account);

      // Register click listeners
      WSViewClickableListener clickListener = new WSViewClickableListener(this);
      findViewById(R.id.button_add_account).setOnClickListener(clickListener);
      findViewById(R.id.button_visit_steam_website).setOnClickListener(clickListener);
    }
    else if (action.equals("confirmCredentials")) {
      if (SteamAuthenticator.confirmCredentials()){
      setResult(RESULT_OK);
      }
      else {
        setResult(RESULT_CANCELED);
      }
    }
    else if (action.equals("updateCredentials")) {
      // Load the Add Account information screen
      setContentView(R.layout.update_credentials);

      // Register click listeners
      WSViewClickableListener clickListener = new WSViewClickableListener(this);
      findViewById(R.id.button_update_credentials).setOnClickListener(clickListener);
    }

  }





  /***********************************************************************************************
  Called when response is received from the server for authentication request. See
  onAuthenticationResult(). Sets the AccountAuthenticatorResult which is sent back to the caller.
  Also sets the authToken in AccountManager for this account.
  @param the confirmCredentials result.
  ***********************************************************************************************/
  public void updateAccount(){
    AccountManager accountManager = AccountManager.get(this);
    SteamAuthenticator.updateAccount(accountManager);

    Intent accountIntent = SteamAuthenticator.getAccountIntent(accountManager);
    setAccountAuthenticatorResult(accountIntent.getExtras());
    setResult(RESULT_OK,accountIntent);

    finish();
  }

}
