////////////////////////////////////////////////////////////////////////////////////////////////
//                                                                                            //
//                                       WATTO STUDIOS                                        //
//                             Java Code, Programs, and Software                              //
//                                    http://www.watto.org                                    //
//                                                                                            //
//                           Copyright (C) 2004-2010  WATTO Studios                           //
//                                                                                            //
// This program is free software; you can redistribute it and/or modify it under the terms of //
// the GNU General Public License published by the Free Software Foundation; either version 2 //
// of the License, or (at your option) any later versions. This program is distributed in the //
// hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranties //
// of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License //
// at http://www.gnu.org for more details. For updates and information about this program, go //
// to the WATTO Studios website at http://www.watto.org or email watto@watto.org . Thanks! :) //
//                                                                                            //
////////////////////////////////////////////////////////////////////////////////////////////////

package org.watto.program.android.sync.steam.authenticator;

import org.watto.android.event.WSPreferenceChangableInterface;
import org.watto.android.event.WSPreferenceClickableInterface;
import org.watto.android.event.listener.WSPreferenceChangableListener;
import org.watto.android.event.listener.WSPreferenceClickableListener;
import org.watto.program.android.sync.steam.R;
import org.watto.program.android.sync.steam.GlobalConstants;
import org.watto.program.android.sync.steam.sync.SyncIntervalWrapper;
import android.accounts.Account;
import android.accounts.AccountManager;
import android.content.ContentResolver;
import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.preference.Preference;
import android.preference.PreferenceActivity;
import android.provider.ContactsContract;


/***********************************************************************************************
Settings for the <code>Account</code>
***********************************************************************************************/
public class AuthenticatorPreferences extends PreferenceActivity implements WSPreferenceClickableInterface, WSPreferenceChangableInterface {

  /***********************************************************************************************
  Performs an action when a <code>Preference</code> value has changed
  @param preference the <code>Preference</code> that triggered the event
  @param value the new value of the <code>Preference</code>
  @return <b>true</b> if the event was handled by this class<br />
          <b>false</b> if the event wasn't handled by this class, and thus should be passed on to
          the parent class for handling.
  ***********************************************************************************************/
  public boolean onChange(Preference preference,Object value){
    String key = preference.getKey();
    if (key.equals("PeriodicSync")) {
      
      Context context = getBaseContext();
      
      // Get the numerical value of the property
      int numberValue = (int)GlobalConstants.DEFAULT_SYNC_INTERVAL;
      try {
        if (value instanceof Number) {
          numberValue = ((Number)value).intValue();
        }
        else if (value instanceof String) {
          numberValue = Integer.parseInt((String)value);
        }
        else {
          numberValue = Integer.parseInt(value.toString());
        }
      }
      catch (Throwable t) { // shouldn't get here!
      }

      
      // Different sync methods for each Android version
      int apiVersion = android.os.Build.VERSION.SDK_INT;
      if (apiVersion <= 7) {
        // <= Android 2.1
        SyncIntervalWrapper.addPeriodicSync(context,numberValue);
      }
      else if (apiVersion >= 8) {
        // Android 2.2+
        AccountManager accountManager = AccountManager.get(context);

        Account[] accounts = accountManager.getAccountsByType(GlobalConstants.ACCOUNT_TYPE);
        if (accounts == null || accounts.length < 1) {
          return false;
        }
        Account account = accounts[0];

        ContentResolver resolver = context.getContentResolver();

        SyncIntervalWrapper.addPeriodicSync(resolver,account,ContactsContract.AUTHORITY,null,numberValue);
      }
    }
    else {
      return false;
    }
    return true;
  }


  /***********************************************************************************************
  Performs an action when a single-click event is triggered on a <code>Preference</code>
  @param preference the <code>Preference</code> that triggered the event
  @return <b>true</b> if the event was handled by this class<br />
          <b>false</b> if the event wasn't handled by this class, and thus should be passed on to
          the parent class for handling.
  ***********************************************************************************************/
  public boolean onClick(Preference preference){
    String key = preference.getKey();
    if (key.equals("DonateUrl")) {
      Intent intent = new Intent(Intent.ACTION_VIEW,Uri.parse("http://www.watto.org/android/donate_steamsync.html"));
      startActivity(intent);
    }
    else if (key.equals("WebsiteUrl")) {
      Intent intent = new Intent(Intent.ACTION_VIEW,Uri.parse("http://www.watto.org/android"));
      startActivity(intent);
    }
    else {
      return false;
    }
    return true;
  }


  /***********************************************************************************************
  Creates the <code>Activity</code>
  ***********************************************************************************************/
  public void onCreate(Bundle bundle){
    super.onCreate(bundle);

    // Add the settings
    addPreferencesFromResource(R.xml.settings);

    // Put listeners on the Settings that need to be actioned directly
    WSPreferenceClickableListener clickListener = new WSPreferenceClickableListener(this);
    findPreference("DonateUrl").setOnPreferenceClickListener(clickListener);
    findPreference("WebsiteUrl").setOnPreferenceClickListener(clickListener);

    WSPreferenceChangableListener changeListener = new WSPreferenceChangableListener(this);
    findPreference("PeriodicSync").setOnPreferenceChangeListener(changeListener);

  }

}
