////////////////////////////////////////////////////////////////////////////////////////////////
//                                                                                            //
//                                       WATTO STUDIOS                                        //
//                             Java Code, Programs, and Software                              //
//                                    http://www.watto.org                                    //
//                                                                                            //
//                           Copyright (C) 2004-2010  WATTO Studios                           //
//                                                                                            //
// This program is free software; you can redistribute it and/or modify it under the terms of //
// the GNU General Public License published by the Free Software Foundation; either version 2 //
// of the License, or (at your option) any later versions. This program is distributed in the //
// hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranties //
// of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License //
// at http://www.gnu.org for more details. For updates and information about this program, go //
// to the WATTO Studios website at http://www.watto.org or email watto@watto.org . Thanks! :) //
//                                                                                            //
////////////////////////////////////////////////////////////////////////////////////////////////

package org.watto.program.android.sync.steam.security;

import org.watto.android.Settings;


/***********************************************************************************************
Convenience methods for establishing OAuth 2.0 authentication to Steam
***********************************************************************************************/
public class SteamAuthProtocol {

  /** The custom url for the user **/
  String customUrl = null;


  /***********************************************************************************************
  Initialises the OAuth provider with the <i>consumerKey</i>, <i>consumerSecret</i> and the 
  <i>callbackUrl</i> for the application
  @param consumerKey the OAuth key for this application
  @param consumerSecret the OAuth secret for this application
  @param callbackUrl the OAuth callback URL for this application
  ***********************************************************************************************/
  public SteamAuthProtocol(){}


  /***********************************************************************************************
  Gets the Custom Url for the user
  @return the <i>customUrl</i>
   ***********************************************************************************************/
  public String getCustomUrl(){
    return customUrl;
  }


  /***********************************************************************************************
  
   ***********************************************************************************************/
  public String getUserUrl(){
    return "http://steamcommunity.com/id/" + customUrl + "/?xml=1";
  }


  /***********************************************************************************************
  
  ***********************************************************************************************/
  public String getUserUrl(long userID){
    return "http://steamcommunity.com/profiles/" + userID + "/?xml=1";
  }


  /***********************************************************************************************
  Loads the authentication <i>code</i> and the <i>accessToken</i> from the <code>Settings</code>
  ***********************************************************************************************/
  public void loadFromSettings(){
    // Load the code and access token from the Settings
    if (Settings.hasApplication()) {
      this.customUrl = Settings.getString("SteamCustomUrl");
    }
    
    // Just in case the URL is already saved as a full URL, trim it down.
    this.customUrl = trimCustomUrl(this.customUrl);
  }
  
  
  /***********************************************************************************************
  Cuts all the http:// bits off the Custom URL if the user specified the URL in full
  @param customUrl the <i>customUrl</i> to trim
  @return the trimmed custom URL
   ***********************************************************************************************/
  public String trimCustomUrl(String customUrl){
    
    // If the user has specified the Custom URL as something like http://steamcommunity.com/id/<customUrl>
    // then we want to cut it down to only be the actual customUrl bit.
    
    int lastSlashPos = customUrl.lastIndexOf('/');
    if (lastSlashPos < 0){
      lastSlashPos = customUrl.lastIndexOf('\\');
    }
    
    if (lastSlashPos < 0){
      // No slashes found - the Custom URL is OK
      return customUrl;
    }
    
    
    // See if the last slash is trailing at the end of the URL
    if (lastSlashPos == customUrl.length()-1){
      // Yep, at the end, so trim it off
      customUrl = customUrl.substring(0,lastSlashPos);
    }
    
    
    // Now trim off any http:// stuff at the beginning
    lastSlashPos = customUrl.lastIndexOf('/');
    if (lastSlashPos < 0){
      lastSlashPos = customUrl.lastIndexOf('\\');
    }
    
    if (lastSlashPos < 0){
      // No slashes found any more - the Custom URL is OK
      return customUrl;
    }
    
    // Trim off all the beginning http:// rubbish
    customUrl = customUrl.substring(lastSlashPos+1);

    return customUrl;
    
  }


  /***********************************************************************************************
  Sets the Custom Url for the user
  @param customUrl the <i>customUrl</i>  
   ***********************************************************************************************/
  public void setCustomUrl(String customUrl){
    
    customUrl = trimCustomUrl(customUrl);
        
    this.customUrl = customUrl;
    Settings.set("SteamCustomUrl",customUrl);
  }

}
